@@ -44,6 +44,7 @@
 
 #define FUSE_USE_VERSION 26
 #include <fuse.h>
+#include <fuse_lowlevel.h>
 
 #define DEBUG_ENABLED 0
 
@@ -2347,15 +2348,9 @@ subthread_main (gpointer data)
   g_signal_handlers_disconnect_by_func (volume_monitor, mount_tracker_mounted_cb, NULL);
   g_signal_handlers_disconnect_by_func (volume_monitor, mount_tracker_unmounted_cb, NULL);
 
-  g_main_loop_unref (subthread_main_loop);
-  subthread_main_loop = NULL;
-
   g_object_unref (volume_monitor);
   volume_monitor = NULL;
 
-  /* Tell the main thread to unmount. Using kill() is necessary according to FUSE maintainers. */
-  kill (getpid (), SIGHUP);
-
   return NULL;
 }
 
@@ -2365,7 +2360,7 @@ name_vanished_handler (GDBusConnection *connection,
                        gpointer user_data)
 {
   /* The daemon died, unmount */
-  g_main_loop_quit (subthread_main_loop);
+  kill (getpid (), SIGHUP);
 }
 
 static void
@@ -2375,7 +2370,7 @@ dbus_connection_closed (GDBusConnection *connection,
                         gpointer user_data)
 {
   /* Session bus died, unmount */
-  g_main_loop_quit (subthread_main_loop);
+  kill (getpid (), SIGHUP);
 }
 
 static void
@@ -2479,10 +2474,15 @@ vfs_destroy (gpointer param)
     g_bus_unwatch_name (daemon_name_watcher);
   g_clear_object (&dbus_conn);
   
-  mount_list_free ();
   if (subthread_main_loop != NULL) 
     g_main_loop_quit (subthread_main_loop);
-  g_object_unref (gvfs);
+
+  if (subthread)
+    g_thread_join (subthread);
+
+  g_clear_pointer (&subthread_main_loop, g_main_loop_unref);
+
+  mount_list_free ();
 }
 
 static struct fuse_operations vfs_oper =
@@ -2525,8 +2525,53 @@ static struct fuse_operations vfs_oper =
 #endif
 };
 
+static void
+set_custom_signal_handlers (void (*handler)(int))
+{
+  struct sigaction sa;
+
+  sigemptyset (&sa.sa_mask);
+  sa.sa_handler = handler;
+  sa.sa_flags = 0;
+
+  sigaction (SIGHUP, &sa, NULL);
+  sigaction (SIGINT, &sa, NULL);
+  sigaction (SIGTERM, &sa, NULL);
+}
+
 gint
 main (gint argc, gchar *argv [])
 {
-  return fuse_main (argc, argv, &vfs_oper, NULL /* user data */);
+  struct fuse *fuse;
+  struct fuse_chan *ch;
+  struct fuse_session *se;
+  char *mountpoint;
+  int multithreaded;
+  int res;
+
+  fuse = fuse_setup (argc, argv, &vfs_oper, sizeof (vfs_oper), &mountpoint,
+                     &multithreaded, NULL /* user data */);
+  if (fuse == NULL)
+    return 1;
+
+  if (multithreaded)
+    res = fuse_loop_mt (fuse);
+  else
+    res = fuse_loop (fuse);
+
+  se = fuse_get_session (fuse);
+  ch = fuse_session_next_chan (se, NULL);
+
+  /* Ignore new signals during exit procedure in order to terminate properly */
+  set_custom_signal_handlers (SIG_IGN);
+  fuse_remove_signal_handlers (se);
+
+  fuse_unmount (mountpoint, ch);
+  fuse_destroy (fuse);
+  free (mountpoint);
+
+  if (res == -1)
+    return 1;
+
+  return 0;
 }
