@@ -42,18 +42,6 @@
 #define G_VFS_BACKEND_AFC_MAX_FILE_SIZE G_MAXINT64
 int g_blocksize = 4096; /* assume this is the default block size */
 
-typedef enum {
-  IOS_UNKNOWN = 0,
-  IOS1,
-  IOS2,
-  IOS3,
-  IOS4,
-  IOS5,
-  IOS6,
-  IOS7,
-  IOS8
-} HostOSVersion;
-
 typedef enum {
   ACCESS_MODE_UNDEFINED = 0,
   ACCESS_MODE_AFC,
@@ -69,7 +57,6 @@ typedef struct {
   char *display_name;
   char *id;
   char *icon_path;
-  gboolean hidden;
   house_arrest_client_t house_arrest;
   afc_client_t afc_cli;
 } AppInfo;
@@ -82,7 +69,6 @@ struct _GVfsBackendAfc {
   char *model;
   gboolean connected;
   AccessMode mode;
-  HostOSVersion version;
 
   idevice_t dev;
   afc_client_t afc_cli; /* for ACCESS_MODE_AFC */
@@ -587,55 +573,6 @@ g_vfs_backend_afc_mount (GVfsBackend *backend,
       g_vfs_backend_set_symbolic_icon_name (G_VFS_BACKEND(self), "phone-apple-iphone-symbolic");
     }
 
-  /* Get the major OS version */
-  value = NULL;
-  self->version = IOS_UNKNOWN;
-  lerr = lockdownd_get_value (lockdown_cli, NULL, "ProductVersion", &value);
-  if (G_LIKELY(g_vfs_backend_lockdownd_check (lerr, G_VFS_JOB(job)) == 0))
-    {
-      if (plist_get_node_type(value) == PLIST_STRING)
-        {
-          char *version_string = NULL;
-
-          plist_get_string_val(value, &version_string);
-          if (version_string)
-            {
-              /* parse version */
-              int maj = 0;
-              int min = 0;
-              int rev = 0;
-
-              sscanf(version_string, "%d.%d.%d", &maj, &min, &rev);
-              free(version_string);
-
-              switch (maj)
-                {
-                case 2:
-                  self->version = IOS2;
-                  break;
-                case 3:
-                  self->version = IOS3;
-                  break;
-                case 4:
-                  self->version = IOS4;
-                  break;
-                case 5:
-                  self->version = IOS5;
-                  break;
-                case 6:
-                  self->version = IOS6;
-                  break;
-                case 7:
-                  self->version = IOS7;
-                  break;
-                case 8:
-                  self->version = IOS8;
-                  break;
-                }
-            }
-        }
-    }
-
   /* save the old client until we connect with the handshake */
   lockdown_cli_old = lockdown_cli;
   lockdown_cli = NULL;
@@ -862,7 +799,7 @@ g_vfs_backend_setup_afc_for_app (GVfsBackendAfc *self,
   house_arrest_client_new (self->dev, lockdown_service, &house_arrest);
   if (house_arrest == NULL)
     {
-      g_warning ("Failed to start house arrest for app %s", info->id);
+      g_warning ("Failed to start house arrest client for app %s", info->id);
       lockdownd_client_free (lockdown_cli);
       lockdownd_service_descriptor_free (lockdown_service);
       return;
@@ -871,7 +808,7 @@ g_vfs_backend_setup_afc_for_app (GVfsBackendAfc *self,
   lockdownd_service_descriptor_free (lockdown_service);
 
   dict = NULL;
-  if (house_arrest_send_command (house_arrest, "VendContainer", info->id) != HOUSE_ARREST_E_SUCCESS ||
+  if (house_arrest_send_command (house_arrest, "VendDocuments", info->id) != HOUSE_ARREST_E_SUCCESS ||
       house_arrest_get_result (house_arrest, &dict) != HOUSE_ARREST_E_SUCCESS)
     {
       g_warning ("Failed to set up house arrest for app %s", info->id);
@@ -936,8 +873,13 @@ g_vfs_backend_parse_house_arrest_path (GVfsBackendAfc *self,
     comps = g_strsplit (path + 1, "/", -1);
 
   setup_afc = force_afc_mount;
-  app = g_strdup (comps[0]);
-  s = g_strjoinv ("/", comps + 1);
+  app = comps[0];
+
+  /* Replace the app path with "Documents" so the gvfs
+   * path of afc://<uuid>/org.gnome.test/foo.txt should
+   * correspond to Documents/foo.txt in the app's container */
+  comps[0] = g_strdup ("Documents");
+  s = g_strjoinv ("/", comps);
   if (*s == '\0')
     {
       g_free (s);
@@ -1642,134 +1584,6 @@ g_vfs_backend_afc_set_info_from_afcinfo (GVfsBackendAfc *self,
   g_file_info_set_is_hidden (info, hidden);
 
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_TRASH, FALSE);
-
-  /* Check for matching thumbnail in .MISC directory */
-  if (g_file_attribute_matcher_matches (matcher, G_FILE_ATTRIBUTE_PREVIEW_ICON) &&
-      self->mode == ACCESS_MODE_AFC &&
-      path != NULL &&
-      g_str_has_prefix (path, "/DCIM/") &&
-      hidden == FALSE &&
-      basename != NULL &&
-      type == G_FILE_TYPE_REGULAR &&
-      strlen (path) > 1 &&
-      strlen (basename) > 4 &&
-      basename[strlen(basename) - 4] == '.')
-    {
-      char *thumb_uri, *thumb_path;
-      char *no_suffix;
-      char **thumb_afcinfo;
-      GFile *thumb_file;
-      const char *suffix;
-
-      GMountSpec *mount_spec;
-      const char *port;
-
-      /* Handle thumbnails for movies as well */
-      if (g_str_has_suffix (path, ".MOV"))
-        suffix = "JPG";
-      else
-        suffix = "THM";
-
-      if (self->version == IOS2)
-        {
-          /* The thumbnails are side-by-side with the
-           * THM files in iOS2 */
-
-          /* Remove the suffix */
-          no_suffix = g_strndup (path, strlen (path) - 3);
-          /* Replace with THM */
-          thumb_path = g_strdup_printf ("%s%s", no_suffix, suffix);
-          g_free (no_suffix);
-        }
-      else if (self->version == IOS3)
-        {
-          char *parent, *ptr;
-          char *thumb_base;
-
-          /* The thumbnails are in the .MISC sub-directory, relative to the
-           * image itself, so:
-           * afc://xxx/DCIM/100APPLE/IMG_0001.JPG
-           * =>
-           * afc://xxx/DCIM/100APPLE/.MISC/IMG_0001.THM
-           */
-
-          /* Parent directory */
-          ptr = strrchr (path, '/');
-          if (ptr == NULL)
-                return;
-          parent = g_strndup (path, ptr - path);
-
-          /* Basename with suffix replaced */
-          no_suffix = g_strndup (basename, strlen (basename) - 3);
-          thumb_base = g_strdup_printf ("%s%s", no_suffix, suffix);
-          g_free (no_suffix);
-
-          /* Full thumbnail path */
-          thumb_path = g_build_filename (parent, ".MISC", thumb_base, NULL);
-
-          g_free (parent);
-          g_free (thumb_base);
-        }
-      else if (self->version >= IOS4)
-        {
-          char **components;
-
-          /* The thumbnails are in the PhotoData/ so:
-           * afc://xxx/DCIM/100APPLE/IMG_0001.JPG
-           * =>
-           * afc://xxx/PhotoData/100APPLE/IMG_0001.THM
-           */
-
-          /* Replace the JPG by THM */
-          no_suffix = g_strndup (path, strlen (path) - 3);
-          thumb_path = g_strdup_printf ("%s%s", no_suffix, suffix);
-          g_free (no_suffix);
-
-          /* Replace DCIM with PhotoData */
-          components = g_strsplit (thumb_path, "/", -1);
-          g_free (thumb_path);
-          for (i = 0; components[i] != NULL; i++)
-            {
-              if (g_str_equal (components[i], "DCIM"))
-                {
-                  g_free (components[i]);
-                  components[i] = g_strdup ("PhotoData");
-                }
-            }
-          thumb_path = g_strjoinv ("/", components);
-          g_strfreev (components);
-        }
-      else
-        {
-          thumb_path = NULL;
-        }
-
-      thumb_afcinfo = NULL;
-      if (thumb_path == NULL ||
-          afc_get_file_info (self->afc_cli, thumb_path, &thumb_afcinfo) != 0)
-        {
-          g_strfreev (thumb_afcinfo);
-          g_free (thumb_path);
-          return;
-        }
-      g_strfreev (thumb_afcinfo);
-
-      /* Get the URI for the thumbnail file */
-      mount_spec = g_vfs_backend_get_mount_spec (G_VFS_BACKEND (self));
-      port = g_mount_spec_get (mount_spec, "port");
-      thumb_uri = g_strdup_printf ("afc://%s%s%s", self->uuid, port ? port : "", thumb_path);
-      g_free (thumb_path);
-      thumb_file = g_file_new_for_uri (thumb_uri);
-      g_free (thumb_uri);
-
-      /* Set preview icon */
-      icon = g_file_icon_new (thumb_file);
-      g_object_unref (thumb_file);
-      g_file_info_set_attribute_object (info,
-                                        G_FILE_ATTRIBUTE_PREVIEW_ICON,
-                                        G_OBJECT (icon));
-      g_object_unref (icon);
-    }
 }
 
 static void
@@ -1808,10 +1622,6 @@ g_vfs_backend_afc_set_info_from_app (GVfsBackendAfc *self,
   g_file_info_set_symbolic_icon (info, symbolic_icon);
   g_object_unref (symbolic_icon);
 
-  /* hidden ? */
-  if (app_info && app_info->hidden)
-    g_file_info_set_is_hidden (info, TRUE);
-
   /* name */
   if (app_info != NULL)
     {
@@ -1938,24 +1748,18 @@ g_vfs_backend_load_apps (GVfsBackendAfc *self)
     {
       plist_t app;
       plist_t p_appid;
-      plist_t p_doctypes;
       plist_t p_name;
       plist_t p_sharing;
       char *s_appid;
       char *s_name;
       guint8 b_sharing;
-      gboolean hidden;
       AppInfo *info;
 
       app = plist_array_get_item(apps, i);
       p_appid = plist_dict_get_item (app, "CFBundleIdentifier");
       p_name = plist_dict_get_item (app, "CFBundleDisplayName");
-      p_doctypes = plist_dict_get_item (app, "CFBundleDocumentTypes");
-      if (plist_array_get_size (p_doctypes) == 0)
-        p_doctypes = NULL;
       p_sharing = plist_dict_get_item (app, "UIFileSharingEnabled");
       b_sharing = FALSE;
-      hidden = FALSE;
       if (p_sharing)
         {
           if (plist_get_node_type (p_sharing) == PLIST_BOOLEAN)
@@ -1977,9 +1781,7 @@ g_vfs_backend_load_apps (GVfsBackendAfc *self)
         }
 
       /* Doesn't support documents, or missing metadata? */
-      if (p_doctypes == NULL && !b_sharing)
-        hidden = TRUE;
-      if (p_appid == NULL || p_name == NULL)
+      if (!b_sharing || p_appid == NULL || p_name == NULL)
         {
           continue;
         }
@@ -2000,7 +1802,6 @@ g_vfs_backend_load_apps (GVfsBackendAfc *self)
       info = g_new0 (AppInfo, 1);
       info->display_name = s_name;
       info->id = s_appid;
-      info->hidden = hidden;
 
       info->icon_path = g_vfs_backend_load_icon (self->sbs, info->id);
 
@@ -2028,7 +1829,6 @@ g_vfs_backend_afc_enumerate (GVfsBackend *backend,
   char **afcinfo = NULL;
   char *new_path = NULL;
   afc_client_t afc_cli;
-  gboolean hide_non_docs = FALSE;
 
   self = G_VFS_BACKEND_AFC(backend);
   g_return_if_fail (self->connected);
@@ -2095,8 +1895,6 @@ g_vfs_backend_afc_enumerate (GVfsBackend *backend,
               g_free (new_path);
               return;
             }
-          if (g_str_equal (new_path, "/"))
-            hide_non_docs = TRUE;
         }
     }
 
@@ -2122,12 +1920,6 @@ g_vfs_backend_afc_enumerate (GVfsBackend *backend,
           info = g_file_info_new ();
           g_vfs_backend_afc_set_info_from_afcinfo (self, info, afcinfo, *ptr, file_path, matcher, flags);
 
-          if (hide_non_docs &&
-              g_str_equal (file_path, "/Documents") == FALSE)
-            {
-              g_file_info_set_is_hidden (info, TRUE);
-            }
-
           g_vfs_job_enumerate_add_info (job, info);
           g_object_unref (G_OBJECT(info));
           g_strfreev (afcinfo);
@@ -2155,7 +1947,6 @@ g_vfs_backend_afc_query_info (GVfsBackend *backend,
   const char *basename, *ptr;
   char **afcinfo = NULL;
   char *new_path;
-  gboolean hide_non_docs = FALSE;
 
   self = G_VFS_BACKEND_AFC(backend);
   g_return_if_fail (self->connected);
@@ -2211,7 +2002,6 @@ g_vfs_backend_afc_query_info (GVfsBackend *backend,
               g_vfs_job_succeeded (G_VFS_JOB(job));
               return;
             }
-          hide_non_docs = TRUE;
           if (G_UNLIKELY(g_vfs_backend_afc_check (afc_get_file_info (app_info->afc_cli, new_path, &afcinfo),
                                                   G_VFS_JOB(job))))
             {
@@ -2230,12 +2020,6 @@ g_vfs_backend_afc_query_info (GVfsBackend *backend,
   g_vfs_backend_afc_set_info_from_afcinfo (self, info, afcinfo, basename, new_path ? new_path : path, matcher, flags);
   if (afcinfo)
     g_strfreev (afcinfo);
-  if (hide_non_docs &&
-      (g_str_equal (new_path, "Documents") ||
-       g_str_has_prefix (new_path, "Documents/")))
-    {
-      g_file_info_set_is_hidden (info, TRUE);
-    }
 
   g_free (new_path);
 
