@@ -324,7 +324,8 @@ send_reply (GVfsJob *job)
   GVfsJobUnmount *op_job = G_VFS_JOB_UNMOUNT (job);
   GVfsBackend *backend = op_job->backend;
 
-  g_debug ("send_reply, failed: %d\n", job->failed);
+  g_debug ("send_reply(%p), failed=%d (%s)\n", job, job->failed,
+           job->failed ? job->error->message : "");
 
   if (job->failed)
     {
