@@ -38,6 +38,7 @@ static gboolean no_dereference = FALSE;
 static gboolean backup = FALSE;
 static gboolean preserve = FALSE;
 static gboolean no_target_directory = FALSE;
+static gboolean show_version = FALSE;
 
 static GOptionEntry entries[] =
 {
@@ -47,6 +48,7 @@ static GOptionEntry entries[] =
   { "preserve", 'p', 0, G_OPTION_ARG_NONE, &preserve, N_("Preserve all attributes"), NULL },
   { "backup", 'b', 0, G_OPTION_ARG_NONE, &backup, N_("Backup existing destination files"), NULL },
   { "no-dereference", 'P', 0, G_OPTION_ARG_NONE, &no_dereference, N_("Never follow symbolic links"), NULL },
+  { "version", 0, 0, G_OPTION_ARG_NONE, &show_version, N_("Show program version"), NULL },
   { NULL }
 };
 
@@ -63,22 +65,34 @@ is_dir (GFile *file)
   return res;
 }
 
-static GTimeVal start_time;
+static gint64 start_time;
+static gint64 previous_time;
 static void
 show_progress (goffset current_num_bytes,
 	       goffset total_num_bytes,
 	       gpointer user_data)
 {
-  GTimeVal tv;
-  char *size;
+  gint64 tv;
+  char *current_size, *total_size, *rate;
 
-  g_get_current_time (&tv);
+  tv = g_get_monotonic_time ();
+  if (tv - previous_time < (G_USEC_PER_SEC / 5) &&
+      current_num_bytes != total_num_bytes)
+    return;
 
-  size = g_format_size (current_num_bytes / MAX (tv.tv_sec - start_time.tv_sec, 1));
-  g_print (_("progress"));
-  g_print (" %"G_GINT64_FORMAT"/%"G_GINT64_FORMAT" (%s/s)\n",
-	   current_num_bytes, total_num_bytes, size);
-  g_free (size);
+  current_size = g_format_size (current_num_bytes);
+  total_size = g_format_size (total_num_bytes);
+  rate = g_format_size (current_num_bytes /
+                        MAX ((tv - start_time) / G_USEC_PER_SEC, 1));
+  g_print ("\r\033[K");
+  g_print (_("Transferred %s out of %s (%s/s)"),
+           current_size, total_size, rate);
+
+  previous_time = tv;
+
+  g_free (current_size);
+  g_free (total_size);
+  g_free (rate);
 }
 
 static void
@@ -103,6 +117,7 @@ main (int argc, char *argv[])
   GFile *source, *dest, *target;
   gboolean dest_is_dir;
   char *basename;
+  char *uri;
   int i;
   GFileCopyFlags flags;
   int retval = 0;
@@ -134,6 +149,12 @@ main (int argc, char *argv[])
       return 1;
     }
 
+  if (show_version)
+    {
+      g_print (PACKAGE_STRING "\n");
+      return 0;
+    }
+
   if (argc <= 2)
     {
       show_help (context, _("Missing operand\n"));
@@ -187,7 +208,7 @@ main (int argc, char *argv[])
 
 
       error = NULL;
-      g_get_current_time (&start_time);
+      start_time = g_get_monotonic_time ();
       if (!g_file_copy (source, target, flags, NULL, progress?show_progress:NULL, NULL, &error))
 	{
 	  if (interactive && g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
@@ -197,15 +218,16 @@ main (int argc, char *argv[])
 	      g_error_free (error);
 	      error = NULL;
 
-	      basename = g_file_get_basename (target);
-	      g_print (_("overwrite %s?"), basename);
-	      g_free (basename);
+	      uri = g_file_get_uri (target);
+	      g_print (_("%s: overwrite ‘%s’? "), argv[0], uri);
+	      g_free (uri);
 
 	      if (fgets(line, sizeof (line), stdin) &&
-		  line[0] == 'y')
+		  (line[0] == 'y' || line[0] == 'Y'))
 		{
 		  flags |= G_FILE_COPY_OVERWRITE;
-		  if (!g_file_copy (source, target, flags, NULL, NULL, NULL, &error))
+		  start_time = g_get_monotonic_time ();
+		  if (!g_file_copy (source, target, flags, NULL, progress?show_progress:NULL, NULL, &error))
 		    goto copy_failed;
 		}
 	    }
@@ -217,6 +239,8 @@ main (int argc, char *argv[])
 	      retval = 1;
 	    }
 	}
+      if (progress && retval == 0)
+	g_print("\n");
 
       g_object_unref (source);
       g_object_unref (target);
